<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * @author Patrik K Lundberg <patrik.kotiranta.lundberg@gmail.com>
 * @author Tor Härnqvist <tor@harnqvist.se>
 * @author Joaquim Homrighausen <joho@webbplatsen.se>
 * @author Per Foreby <per@foreby.se>
 * @author Nicklas Henriksson <nicklas[at]nihe.se>
 * @author Håkan Sandell <hakan.sandell@home.se>
 * @author Dennis Karlsson
 * @author Tormod Otter Johansson <tormod@latast.se>
 * @author Tormod Johansson <tormod.otter.johansson@gmail.com>
 * @author Pontus Bergendahl <pontus.bergendahl@gmail.com>
 * @author Emil Lind <emil@sys.nu>
 * @author Bogge Bogge <bogge@bogge.com>
 * @author Peter Åström <eaustreum@gmail.com>
 * @author Henrik <henrik@idealis.se>
 * @author Hans Iwan Bratt <hibratt@gmail.com>
 * @author Mikael Bergström <krank23@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '”';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '’';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Redigera sidan';
$lang['btn_source']            = 'Visa källkod';
$lang['btn_show']              = 'Visa sidan';
$lang['btn_create']            = 'Skapa sidan';
$lang['btn_search']            = 'Sök';
$lang['btn_save']              = 'Spara';
$lang['btn_preview']           = 'Granska';
$lang['btn_top']               = 'Till början av sidan';
$lang['btn_newer']             = '<< nyare';
$lang['btn_older']             = 'äldre >>';
$lang['btn_revs']              = 'Historik';
$lang['btn_recent']            = 'Nyligen ändrat';
$lang['btn_upload']            = 'Ladda upp';
$lang['btn_cancel']            = 'Avbryt';
$lang['btn_index']             = 'Index';
$lang['btn_secedit']           = 'Redigera';
$lang['btn_login']             = 'Logga in';
$lang['btn_logout']            = 'Logga ut';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Uppdatera';
$lang['btn_delete']            = 'Radera';
$lang['btn_back']              = 'Tillbaka';
$lang['btn_backlink']          = 'Tillbakalänkar';
$lang['btn_subscribe']         = 'Prenumerera på ändringar';
$lang['btn_profile']           = 'Uppdatera profil';
$lang['btn_reset']             = 'Återställ';
$lang['btn_resendpwd']         = 'Skapa nytt lösenord';
$lang['btn_draft']             = 'Redigera utkast';
$lang['btn_recover']           = 'Återskapa utkast';
$lang['btn_draftdel']          = 'Radera utkast';
$lang['btn_revert']            = 'Återställ';
$lang['btn_register']          = 'Registrera';
$lang['btn_apply']             = 'Verkställ';
$lang['btn_media']             = 'Mediahanteraren';
$lang['btn_deleteuser']        = 'Ta bort Mitt Konto';
$lang['btn_img_backto']        = 'Tillbaka till %s';
$lang['btn_mediaManager']      = 'Se mediahanteraren';
$lang['loggedinas']            = 'Inloggad som:';
$lang['user']                  = 'Användarnamn';
$lang['pass']                  = 'Lösenord';
$lang['newpass']               = 'Nytt lösenord';
$lang['oldpass']               = 'Bekräfta nuvarande lösenord';
$lang['passchk']               = 'en gång till';
$lang['remember']              = 'Kom ihåg mig';
$lang['fullname']              = 'Namn';
$lang['email']                 = 'E-post';
$lang['profile']               = 'Användarprofil';
$lang['badlogin']              = 'Felaktigt användarnamn eller lösenord.';
$lang['badpassconfirm']        = 'Ledsen, lösenordet var felaktigt';
$lang['minoredit']             = 'Små ändringar';
$lang['draftdate']             = 'Utkast automatiskt sparat';
$lang['nosecedit']             = 'Sidan ändrades medan du skrev, sektionsinformationen var inte uppdaterad. Laddar hela sidan istället.';
$lang['searchcreatepage']      = 'Om du inte hittade det du sökte så kan du skapa eller editera sidan %s som är döpt efter din sökning.';
$lang['search_fullresults']    = 'Heltext resultat';
$lang['js']['search_toggle_tools'] = 'Växla sökverktyg';
$lang['js']['willexpire']      = 'Ditt redigeringslås för detta dokument kommer snart att upphöra.\nFör att undvika versionskonflikter bör du förhandsgranska ditt dokument för att förlänga redigeringslåset.';
$lang['js']['notsavedyet']     = 'Det finns ändringar som inte är sparade.
Är du säker på att du vill fortsätta?';
$lang['js']['searchmedia']     = 'Sök efter filer';
$lang['js']['keepopen']        = 'Lämna fönstret öppet efter val av fil';
$lang['js']['hidedetails']     = 'Dölj detaljer';
$lang['js']['mediatitle']      = 'Länkinställningar';
$lang['js']['mediadisplay']    = 'Länktyp';
$lang['js']['mediaalign']      = 'Justering';
$lang['js']['mediasize']       = 'Bildstorlek';
$lang['js']['mediatarget']     = 'Länköppning';
$lang['js']['mediaclose']      = 'Stäng';
$lang['js']['mediainsert']     = 'Infoga';
$lang['js']['mediadisplayimg'] = 'Visa bilden.';
$lang['js']['mediadisplaylnk'] = 'Visa endast länken.';
$lang['js']['mediasmall']      = 'Liten storlek';
$lang['js']['mediamedium']     = 'Mellanstor storlek';
$lang['js']['medialarge']      = 'Stor storlek';
$lang['js']['mediaoriginal']   = 'Originalstorlek';
$lang['js']['medialnk']        = 'Länk till detalj sida';
$lang['js']['mediadirect']     = 'Direktlänk till originalet';
$lang['js']['medianolnk']      = 'Ingen länk';
$lang['js']['medianolink']     = 'Länka inte bilden';
$lang['js']['medialeft']       = 'Justera bilden till vänster.';
$lang['js']['mediaright']      = 'Justera bilden till höger.';
$lang['js']['mediacenter']     = 'Centrera bilden.';
$lang['js']['medianoalign']    = 'Använd ingen justering';
$lang['js']['nosmblinks']      = 'Länkning till Windowsresurser fungerar bara med Microsofts Internet Explorer.
Du kan fortfarande klippa och klistra in länken om du använder en annan webbläsare än MSIE.';
$lang['js']['linkwiz']         = 'Snabbguide Länkar';
$lang['js']['linkto']          = 'Länk till:';
$lang['js']['del_confirm']     = 'Vill du verkligen radera?';
$lang['js']['restore_confirm'] = 'Återställa denna version?';
$lang['js']['media_diff']      = 'Se skillnader:';
$lang['js']['media_diff_both'] = 'Sida vid sida';
$lang['js']['media_diff_opacity'] = 'Genomskinlig';
$lang['js']['media_diff_portions'] = 'Svep';
$lang['js']['media_select']    = 'Välj filer...';
$lang['js']['media_upload_btn'] = 'Ladda upp';
$lang['js']['media_done_btn']  = 'Färdig';
$lang['js']['media_drop']      = 'Släpp filer här för att ladda upp';
$lang['js']['media_cancel']    = 'ta bort';
$lang['js']['media_overwrt']   = 'Skriv över existerande filer';
$lang['search_exact_match']    = 'Exakt träff';
$lang['search_starts_with']    = 'Börjar med';
$lang['search_ends_with']      = 'Slutar med';
$lang['search_contains']       = 'Innehåller';
$lang['search_custom_match']   = 'Anpassad';
$lang['search_any_ns']         = 'Alla namespaces';
$lang['search_any_time']       = 'Alla tider';
$lang['search_past_7_days']    = 'Senaste veckan';
$lang['search_past_month']     = 'Senaste månaden';
$lang['search_past_year']      = 'Senaste året';
$lang['search_sort_by_hits']   = 'Sortera efter träffar';
$lang['search_sort_by_mtime']  = 'Sortera efter senast modifierad';
$lang['regmissing']            = 'Du måste fylla i alla fälten.';
$lang['reguexists']            = 'Det finns redan en användare med det användarnamnet.';
$lang['regsuccess']            = 'Användarkontot skapat, lösenordet har skickats via e-post.';
$lang['regsuccess2']           = 'Användarkontot skapat.';
$lang['regfail']               = 'Användaren kunde inte skapas.';
$lang['regmailfail']           = 'Ett fel uppstod när ditt lösenord skulle skickas via e-post. Var god kontakta administratören!';
$lang['regbadmail']            = 'Den angivna e-postadressen verkar vara ogiltig - om du anser detta felaktigt, var god kontakta administratören';
$lang['regbadpass']            = 'De två angivna lösenorden är inte identiska. Försök igen.';
$lang['regpwmail']             = 'Ditt DokuWikilösenord';
$lang['reghere']               = 'Har du inte ett konto än? Skaffa ett';
$lang['profna']                = 'Denna wiki stödjer inte ändringar av profiler';
$lang['profnochange']          = 'Ingenting ändrades, inget att göra.';
$lang['profnoempty']           = 'Namn och e-postadress måste fyllas i.';
$lang['profchanged']           = 'Användarprofilen uppdaterad.';
$lang['profnodelete']          = 'Den här wiki:n stödjer ej borttagning av användare';
$lang['profdeleteuser']        = 'Radera kontot';
$lang['profdeleted']           = 'Ditt användarkonto har raderats från den här wiki:n';
$lang['profconfdelete']        = 'Jag vill ta bort mitt konto/inlogg på den här wiki:n <br/> Denna åtgärd går ej att ångra.';
$lang['profconfdeletemissing'] = 'Bekräftelse-kryssrutan är ej markerad';
$lang['proffail']              = 'Användarprofilen uppdaterades ej.';
$lang['pwdforget']             = 'Glömt ditt lösenord? Ordna ett nytt';
$lang['resendna']              = 'Den här wikin stödjer inte utskick av lösenord.';
$lang['resendpwd']             = 'Sätt lösenord för';
$lang['resendpwdmissing']      = 'Du måste fylla i alla fält.';
$lang['resendpwdnouser']       = 'Den här användaren hittas inte i databasen.';
$lang['resendpwdbadauth']      = 'Den här verifieringskoden är inte giltig. Kontrollera att du använde hela verifieringslänken.';
$lang['resendpwdconfirm']      = 'En verifieringslänk har skickats med e-post.';
$lang['resendpwdsuccess']      = 'Ditt nya lösenord har skickats med e-post.';
$lang['license']               = 'Om inte annat angivet, innehållet i denna wiki är licensierat under följande licenser:';
$lang['licenseok']             = 'Notera: Genom att ändra i denna sidan så accepterar du att licensiera ditt bidrag under följande licenser:';
$lang['searchmedia']           = 'Sök efter filnamn:';
$lang['searchmedia_in']        = 'Sök i %s';
$lang['txt_upload']            = 'Välj fil att ladda upp:';
$lang['txt_filename']          = 'Ladda upp som (ej obligatoriskt):';
$lang['txt_overwrt']           = 'Skriv över befintlig fil';
$lang['maxuploadsize']         = 'Max %s per uppladdad fil.';
$lang['allowedmime']           = 'Lista av alla tillåtna extensions';
$lang['lockedby']              = 'Låst av:';
$lang['lockexpire']            = 'Lås upphör att gälla:';
$lang['rssfailed']             = 'Ett fel uppstod när detta RSS-flöde skulle hämtas: ';
$lang['nothingfound']          = 'Inga filer hittades.';
$lang['mediaselect']           = 'Mediafiler';
$lang['uploadsucc']            = 'Uppladdningen lyckades';
$lang['uploadfail']            = 'Uppladdningen misslyckades, fel filskydd?';
$lang['uploadwrong']           = 'Uppladdning nekad. Filändelsen är inte tillåten!';
$lang['uploadexist']           = 'Filen finns redan. Ingenting gjordes.';
$lang['uploadbadcontent']      = 'Det uppladdade innehållet stämde inte överens med filändelsen %s.';
$lang['uploadspam']            = 'Uppladdningen stoppades av spärrlistan för spam.';
$lang['uploadxss']             = 'Uppladdningen stoppades på grund av eventuellt skadligt innehåll.';
$lang['uploadsize']            = 'Den uppladdade filen är för stor. (max. %s)';
$lang['deletesucc']            = 'Filen "%s" har raderats.';
$lang['deletefail']            = 'Kunde inte radera "%s" - kontrollera filskydd.';
$lang['mediainuse']            = 'Filen "%s" har inte raderats - den används fortfarande.';
$lang['namespaces']            = 'Namnrymder';
$lang['mediafiles']            = 'Tillgängliga filer i';
$lang['accessdenied']          = 'Du får inte läsa den här sidan.';
$lang['mediausage']            = 'Använd följande syntax för att referera till denna fil:';
$lang['mediaview']             = 'Visa originalfilen';
$lang['mediaroot']             = 'rot';
$lang['mediaupload']           = 'Här kan du ladda upp en fil till den nuvarande namnrymden. För att skapa undernamnrymder, skriv dem före filnamnet under "Ladda upp som". Separera namnrymd och filnamn med kolon.';
$lang['mediaextchange']        = 'Filändelsen ändrad från .%s till .%s!';
$lang['reference']             = 'Referenser till';
$lang['ref_inuse']             = 'Filen kan inte raderas eftersom den fortfarande används av följande sidor:';
$lang['ref_hidden']            = 'Vissa referenser är på sidor som du inte har rätt att läsa';
$lang['hits']                  = 'Träffar';
$lang['quickhits']             = 'Matchande sidnamn';
$lang['toc']                   = 'Innehållsförteckning';
$lang['current']               = 'aktuell';
$lang['yours']                 = 'Din version';
$lang['diff']                  = 'visa skillnader mot aktuell version';
$lang['diff2']                 = 'Visa skillnader mellan valda versioner';
$lang['difflink']              = 'Länk till den här jämförelsesidan';
$lang['diff_type']             = 'Visa skillnader:';
$lang['diff_inline']           = 'Exakt träff';
$lang['diff_side']             = 'Sida vid sida';
$lang['diffprevrev']           = 'Föregående version.';
$lang['diffnextrev']           = 'Nästa version.';
$lang['difflastrev']           = 'Senaste version.';
$lang['diffbothprevrev']       = 'Börjar med';
$lang['diffbothnextrev']       = 'Slutar med';
$lang['line']                  = 'Rad';
$lang['breadcrumb']            = 'Spår:';
$lang['youarehere']            = 'Här är du:';
$lang['lastmod']               = 'Senast uppdaterad:';
$lang['by']                    = 'av';
$lang['deleted']               = 'raderad';
$lang['created']               = 'skapad';
$lang['restored']              = 'tidigare version återställd (%s)';
$lang['external_edit']         = 'extern redigering';
$lang['summary']               = 'Redigeringskommentar';
$lang['noflash']               = '<a href="http://get.adobe.com/flashplayer">Adobe Flash Plugin</a> behövs för att visa detta innehåll.';
$lang['download']              = 'Ladda ner kodfragmentet';
$lang['tools']                 = 'Verktyg';
$lang['user_tools']            = 'Användarverktyg';
$lang['site_tools']            = 'Webbverktyg';
$lang['page_tools']            = 'Sidverktyg';
$lang['skip_to_content']       = 'hoppa till innehåll';
$lang['sidebar']               = 'Sidmeny';
$lang['mail_newpage']          = 'sida tillagd:';
$lang['mail_changed']          = 'sida ändrad:';
$lang['mail_subscribe_list']   = 'sidor ändrade i namnrymd:';
$lang['mail_new_user']         = 'Ny användare:';
$lang['mail_upload']           = 'fil uppladdad:';
$lang['changes_type']          = 'Se ändringar av';
$lang['pages_changes']         = 'Sidor';
$lang['media_changes']         = 'Mediafiler';
$lang['both_changes']          = 'Både sidor och mediafiler';
$lang['qb_bold']               = 'Fet text';
$lang['qb_italic']             = 'Kursiv text';
$lang['qb_underl']             = 'Understruken text';
$lang['qb_code']               = 'Kodtext';
$lang['qb_strike']             = 'Överstruken text';
$lang['qb_h1']                 = 'Rubrik nivå 1';
$lang['qb_h2']                 = 'Rubrik nivå 2';
$lang['qb_h3']                 = 'Rubrik nivå 3';
$lang['qb_h4']                 = 'Rubrik nivå 4';
$lang['qb_h5']                 = 'Rubrik nivå 5';
$lang['qb_h']                  = 'Rubrik';
$lang['qb_hs']                 = 'Välj Rubrik';
$lang['qb_hplus']              = 'Större Rubrik';
$lang['qb_hminus']             = 'Mindre Rubrik';
$lang['qb_hequal']             = 'Rubrik samma nivå.';
$lang['qb_link']               = 'Intern Länk';
$lang['qb_extlink']            = 'Extern Länk';
$lang['qb_hr']                 = 'Horisontell linje';
$lang['qb_ol']                 = 'Punkt i sorterad lista';
$lang['qb_ul']                 = 'Punkt i osorterad lista';
$lang['qb_media']              = 'Lägg till bilder och andra filer';
$lang['qb_sig']                = 'Infoga signatur';
$lang['qb_smileys']            = 'Smileys';
$lang['qb_chars']              = 'Specialtecken';
$lang['upperns']               = 'hoppa till föräldernamnrymd';
$lang['metaedit']              = 'Redigera metadata';
$lang['metasaveerr']           = 'Skrivning av metadata misslyckades';
$lang['metasaveok']            = 'Metadata sparad';
$lang['img_title']             = 'Rubrik:';
$lang['img_caption']           = 'Bildtext:';
$lang['img_date']              = 'Datum:';
$lang['img_fname']             = 'Filnamn:';
$lang['img_fsize']             = 'Storlek:';
$lang['img_artist']            = 'Fotograf:';
$lang['img_copyr']             = 'Copyright:';
$lang['img_format']            = 'Format:';
$lang['img_camera']            = 'Kamera:';
$lang['img_keywords']          = 'Nyckelord:';
$lang['img_width']             = 'Bredd:';
$lang['img_height']            = 'Höjd:';
$lang['subscr_subscribe_success'] = 'La till %s till prenumerationslista %s';
$lang['subscr_subscribe_error'] = 'Error att lägga till %s till prenumerationslista för %s';
$lang['subscr_subscribe_noaddress'] = 'Det finns ingen adress associerad med din inloggning, du kan inte bli tillagd i prenumerationslistan';
$lang['subscr_unsubscribe_success'] = '%s borttagen från prenumerationslistan för %s';
$lang['subscr_unsubscribe_error'] = 'Fel vid borttagning av %s från prenumerationslista %s';
$lang['subscr_already_subscribed'] = '%s prenumererar redan på %s';
$lang['subscr_not_subscribed'] = '%s prenumererar inte på %s';
$lang['subscr_m_not_subscribed'] = 'Du prenumererar inte på denna sida eller namnrymd.';
$lang['subscr_m_new_header']   = 'Lägg till prenumeration';
$lang['subscr_m_current_header'] = 'Nuvarande prenumerationer';
$lang['subscr_m_unsubscribe']  = 'Avsluta prenumeration';
$lang['subscr_m_subscribe']    = 'Prenumerera';
$lang['subscr_m_receive']      = 'Ta emot';
$lang['subscr_style_every']    = 'skicka epost vid varje ändring';
$lang['subscr_style_digest']   = 'Samlings-e-brev av ändringar för varje sida (var %.2f dag)';
$lang['subscr_style_list']     = 'lista över ändrade sidor sedan senaste e-post (varje %.2f dag)';
$lang['authtempfail']          = 'Tillfälligt fel på användarautentisering. Om felet kvarstår, var vänlig meddela wikiadministratören.';
$lang['i_chooselang']          = 'Välj språk';
$lang['i_installer']           = 'Installation av DokuWiki';
$lang['i_wikiname']            = 'Wikins namn';
$lang['i_enableacl']           = 'Aktivera behörighetslistan (ACL) (rekommenderas)';
$lang['i_superuser']           = 'Användarnamn för administratören';
$lang['i_problems']            = 'Installationsprogrammet hittade några problem som visas nedan. Du kan inte fortsätta innan du har fixat dem.';
$lang['i_modified']            = 'Av säkerhetsskäl fungerar det här skriptet bara med en ny och omodifierad installation av Dokuwiki.
                         Du får antingen packa upp det nedladdade paketet på nytt, eller konsultera de kompletta
                         <a href="https://www.dokuwiki.org/install">instruktionerna för installation av Dokuwiki</a>';
$lang['i_funcna']              = 'PHP-funktionen <code>%s</code> är inte tillgänglig. Kanske ditt webbhotell har avaktiverat den av någon anledning?';
$lang['i_disabled']            = 'Det är avstängt av din leverantör.';
$lang['i_funcnmail']           = '<b>Note:</b> PHP mail funktionen är inte tillgänglig. %s Om det är fortsatt otillgängligt kan du installera <a href="https://www.dokuwiki.org/plugin:smtp">smtp pluginet</a>';
$lang['i_phpver']              = 'Din PHP-version <code>%s</code> är lägre än vad som krävs <code>%s</code>. Du behöver uppgradera din PHP-installation.';
$lang['i_mbfuncoverload']      = 'mbstring.func_overload måste inaktiveras i php.ini för att använda DokuWiki.';
$lang['i_urandom']             = 'Innehåller';
$lang['i_permfail']            = '<code>%s</code> är inte skrivbar av DokuWiki. Du behöver ändra filskyddet på den här katalogen!';
$lang['i_confexists']          = '<code>%s</code> finns redan';
$lang['i_writeerr']            = 'Kan inte skapa <code>%s</code>. Kontrollera filskyddet på kataloger/filer och skapa filen manuellt.';
$lang['i_badhash']             = 'okänd eller ändrad dokuwiki.php (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - felaktig eller blank';
$lang['i_success']             = 'Konfigurationen avslutades utan fel. Du kan radera filen install.php nu. Fortsätt till
                        <a href="doku.php?id=wiki:welcome">din nya DokuWiki</a>.';
$lang['i_failure']             = 'Fel uppstod vid skrivning av konfigurationsfilerna. Du kan behöva ordna till dem manuellt innan
                         du kan använda <a href="doku.php?id=wiki:welcome">din nya DokuWiki</a>.';
$lang['i_policy']              = 'Initial ACL-policy';
$lang['i_pol0']                = 'Öppen wiki (alla får läsa, skriva och ladda upp filer)';
$lang['i_pol1']                = 'Publik wiki (alla får läsa, registrerade användare för skriva och ladda upp filer)';
$lang['i_pol2']                = 'Sluten wiki (endast registrerade användare får läsa, skriva och ladda upp filer)';
$lang['i_allowreg']            = 'Tillåt användare att registrera sig själva';
$lang['i_retry']               = 'Försök igen';
$lang['i_license']             = 'Vänligen välj licens du vill använda för ditt innehåll:';
$lang['i_license_none']        = 'Visa ingen licensinformation';
$lang['i_pop_field']           = 'Hjälp oss förbättra DokuWiki upplevelsen:';
$lang['i_pop_label']           = 'Sänd anonym användarinformation en gång i månaden till DokuWikis utvecklare';
$lang['recent_global']         = 'Du bevakar ändringar i namnrymden <b>%s</b>. Du kan också titta på <a href="%s">senaste ändringar för hela wikin</a>.';
$lang['years']                 = '%d år sedan';
$lang['months']                = '%d månader sedan';
$lang['weeks']                 = '%d veckor sedan';
$lang['days']                  = '%d dagar sedan';
$lang['hours']                 = '%d timmar sedan';
$lang['minutes']               = '%d minuter sedan';
$lang['seconds']               = '%d sekunder sedan';
$lang['wordblock']             = 'Din ändring sparades inte för att den innehåller otillåten text (spam).';
$lang['media_uploadtab']       = 'Ladda upp';
$lang['media_searchtab']       = 'Sök';
$lang['media_file']            = 'Fil';
$lang['media_viewtab']         = 'Visa';
$lang['media_edittab']         = 'Redigera';
$lang['media_historytab']      = 'Historik';
$lang['media_list_thumbs']     = 'Miniatyrbild';
$lang['media_list_rows']       = 'Rader';
$lang['media_sort_name']       = 'Namn';
$lang['media_sort_date']       = 'Datum';
$lang['media_namespaces']      = 'Visa namnrymd';
$lang['media_files']           = 'Filer i %s';
$lang['media_upload']          = 'Ladda upp till %s';
$lang['media_search']          = 'Sök i %s';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s vid %s';
$lang['media_edit']            = 'Redigera %s';
$lang['media_history']         = '%s-historik';
$lang['media_meta_edited']     = 'metadata redigerat';
$lang['media_perm_read']       = 'Du har tyvärr inte tillräckliga behörigheter för att läsa filer.';
$lang['media_perm_upload']     = 'Du har tyvärr inte tillräckliga behörigheter för att ladda upp filer.';
$lang['media_update']          = 'Ladda upp ny version';
$lang['media_restore']         = 'Återställ denna version';
$lang['media_acl_warning']     = 'Listan kanske inte är ';
$lang['email_fail']            = 'PHP mail() saknas eller är inaktiverad. Följande mejl skickades inte:';
$lang['currentns']             = 'Nuvarande namnrymd.';
$lang['searchresult']          = 'Sökresultat';
$lang['plainhtml']             = 'Ren HTML';
$lang['wikimarkup']            = 'Wiki Markup';
$lang['page_nonexist_rev']     = 'Sidan fanns inte på %s. Den blev sedermera skapad på <a href="%s">%s</a>.';
$lang['unable_to_parse_date']  = 'Oförmögen att processera i parameter "%s".';
$lang['email_signature_text']  = 'Detta meddelande har skapats av DokuWiki på
@DOKUWIKIURL@';
